//---------------------------------------------------------------------------
#ifndef swdisprtfchapH
#define swdisprtfchapH
//---------------------------------------------------------------------------
#include <vcl\SysUtils.hpp>
#include <vcl\Controls.hpp>
#include <vcl\Classes.hpp>
#include <vcl\Forms.hpp>
#include <vcl\ComCtrls.hpp>
#include <vcl\StdCtrls.hpp>
#include <swtext.h>
#include <swdisprtf.h>
//---------------------------------------------------------------------------

class SWDispRTFChap : public SWDispRTF {
protected:

		bool FCurVerseMrk;
		bool FCurVersePos;
		bool FMarkCurrentVerse;
		bool FAutoPosition;
		
		virtual void __fastcall Loaded(void);
public:
	__fastcall SWDispRTFChap(TComponent* Owner);
	__fastcall ~SWDispRTFChap();

	virtual char Display(SWModule &imodule);
__published:
		__property bool               CurVersePos        = {read=FCurVersePos,         write=FCurVersePos,        default=true};
		__property bool               CurVerseMrk        = {read=FCurVerseMrk,         write=FCurVerseMrk,        default=true};
		__property bool               MarkCurrentVerse   = {read=FMarkCurrentVerse,    write=FMarkCurrentVerse,   default=true};
		__property bool               AutoPosition       = {read=FAutoPosition,        write=FAutoPosition,       default=true};
};
//---------------------------------------------------------------------------
#endif

